PALM-meteo: palmmeteo_stdplugins.aladin.BilinearRegridder Class Reference

PALM-meteo

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | List of all members
palmmeteo_stdplugins.aladin.BilinearRegridder Class Reference
Inheritance diagram for palmmeteo_stdplugins.aladin.BilinearRegridder:
[legend]
Collaboration diagram for palmmeteo_stdplugins.aladin.BilinearRegridder:
[legend]

## Public Member Functions
| __init__ (self, projected_x, projected_y, preloaded=False)
| regrid (self, data)

## Public Attributes
| shape
| rank
| y0
| x0
| ys
| ylen
| xs
| xlen
| y1
| x1
| weights

## Detailed Description

    Bilinear regridder for multidimensional data.

    By standard, the last two dimensions are always Y,X in that order.

## Constructor & Destructor Documentation

## ◆ __init__()

palmmeteo_stdplugins.aladin.BilinearRegridder.__init__ | ( |  | self,
|  |  | projected_x,
|  |  | projected_y,
|  |  | preloaded = `False`
| ) |  |

## Member Function Documentation

## ◆ regrid()

palmmeteo_stdplugins.aladin.BilinearRegridder.regrid | ( |  | self,
|  |  | data
| ) |  |

## Member Data Documentation

## ◆ rank

palmmeteo_stdplugins.aladin.BilinearRegridder.rank

## ◆ shape

palmmeteo_stdplugins.aladin.BilinearRegridder.shape

## ◆ weights

palmmeteo_stdplugins.aladin.BilinearRegridder.weights

## ◆ x0

palmmeteo_stdplugins.aladin.BilinearRegridder.x0

## ◆ x1

palmmeteo_stdplugins.aladin.BilinearRegridder.x1

## ◆ xlen

palmmeteo_stdplugins.aladin.BilinearRegridder.xlen

## ◆ xs

palmmeteo_stdplugins.aladin.BilinearRegridder.xs

## ◆ y0

palmmeteo_stdplugins.aladin.BilinearRegridder.y0

## ◆ y1

palmmeteo_stdplugins.aladin.BilinearRegridder.y1

## ◆ ylen

palmmeteo_stdplugins.aladin.BilinearRegridder.ylen

## ◆ ys

palmmeteo_stdplugins.aladin.BilinearRegridder.ys

The documentation for this class was generated from the following file:

- palmmeteo_stdplugins/aladin.py